@@ -3,7 +3,7 @@
 """Package entry point."""
 
 
-from stlearn.gui import main
+from stlearn.app import main
 
 
 if __name__ == "__main__":  # pragma: no cover
