@@ -11,6 +11,7 @@ def labels(
     adata: AnnData,
     label_filepath: str = None,
     index_col: int = 0,
+    use_label: str = None,
     sep: str = "\t",
     copy: bool = False,
 ) -> Optional[AnnData]:
@@ -21,6 +22,7 @@ def labels(
     ----------
     adata: AnnData          The data object to add L-R info into
     label_filepath: str     The path to the label transfer results file
+    use_label: str          Where to store the label_transfer results, defaults to 'predictions' in adata.obs & 'label_transfer' in adata.uns.
     sep: str                Separator of the csv file
     copy: bool              Copy flag indicating copy or direct edit
 
@@ -30,18 +32,17 @@ def labels(
 
     """
     labels = pd.read_csv(label_filepath, index_col=index_col, sep=sep)
-    adata.uns["label_transfer"] = labels.drop(
-        ["predicted.id", "prediction.score.max"], axis=1
-    )
+    uns_key = "label_transfer" if type(use_label) == type(None) else use_label
+    adata.uns[uns_key] = labels.drop(["predicted.id", "prediction.score.max"], axis=1)
 
-    key_add = "predictions"
+    key_add = "predictions" if type(use_label) == type(None) else use_label
     key_source = "predicted.id"
     adata.obs[key_add] = pd.Categorical(
         values=np.array(labels[key_source]).astype("U"),
         categories=natsorted(labels[key_source].unique().astype("U")),
     )
 
-    print("label transfer results added to adata.uns['label_transfer']")
-    print("predicted label added to adata.obs['predictions'].")
+    print(f"label transfer results added to adata.uns['{uns_key}']")
+    print(f"predicted label added to adata.obs['{key_add}'].")
 
     return adata if copy else None
