@@ -20,15 +20,15 @@ def annotation(
     adata
         Annotated data matrix.
     label_list
-        List of the labels which assigned to current clustering result.
+        List of the labels which assigned to current cluster result.
     use_label
-        Choosing clustering type.
+        Choosing cluster type.
     copy
         Return a copy instead of writing to adata.
     Returns
     -------
     Depending on `copy`, returns or updates `adata` with the following fields.
-    **[clustering method name]_anno** : `adata.obs` field
+    **[cluster method name]_anno** : `adata.obs` field
         The annotation of cluster results.
     """
 
@@ -38,9 +38,9 @@ def annotation(
     if len(label_list) != len(adata.obs[use_label].unique()):
         raise ValueError("Please give the correct number of label list!")
 
-    adata.obs[use_label + '_anno'] = adata.obs[use_label]
-    adata.obs[use_label + '_anno'].cat.categories = label_list
+    adata.obs[use_label + "_anno"] = adata.obs[use_label]
+    adata.obs[use_label + "_anno"].cat.categories = label_list
 
-    print("The annotation is added to adata.obs['" + use_label + "_anno"+"']")
+    print("The annotation is added to adata.obs['" + use_label + "_anno" + "']")
 
     return adata if copy else None
