@@ -58,6 +58,10 @@ def tiling(
     if image.dtype == np.float32 or image.dtype == np.float64:
         image = (image * 255).astype(np.uint8)
     img_pillow = Image.fromarray(image)
+
+    if img_pillow.mode == "RGBA":
+        img_pillow = img_pillow.convert("RGB")
+
     tile_names = []
 
     with tqdm(
@@ -73,7 +77,7 @@ def tiling(
             tile = img_pillow.crop(
                 (imagecol_left, imagerow_down, imagecol_right, imagerow_up)
             )
-            tile.thumbnail((target_size, target_size), Image.ANTIALIAS)
+            tile.thumbnail((target_size, target_size), Image.Resampling.LANCZOS)
             tile.resize((target_size, target_size))
             tile_name = str(imagecol) + "-" + str(imagerow) + "-" + str(crop_size)
             out_tile = Path(out_path) / (tile_name + ".jpeg")
