@@ -4,7 +4,8 @@ Author: Duy Pham
 Date: 20 Feb 2021
 """
 
-from typing import Optional, Union, Mapping  # Special
+from lib2to3.pgen2.token import OP
+from typing import Optional, Union, Mapping, List  # Special
 from typing import Sequence, Iterable  # ABCs
 from typing import Tuple  # Classes
 
@@ -47,6 +48,7 @@ class SpatialBasePlot(Spatial):
         show_image: Optional[bool] = True,
         show_color_bar: Optional[bool] = True,
         color_bar_label: Optional[str] = "",
+        zoom_coord: Optional[float] = None,
         crop: Optional[bool] = True,
         margin: Optional[bool] = 100,
         size: Optional[float] = 7,
@@ -129,10 +131,11 @@ class SpatialBasePlot(Spatial):
         if show_image:
             self._add_image(self.ax)
 
-        ## Don't want to do this, since then can't build on figure when parsing
-        ## fig, ax as input
-        # if show_plot == False:
-        #     plt.close(self.fig)
+        if zoom_coord is not None:
+            self._zoom_image(self.ax, zoom_coord)
+            crop = False
+        if crop:
+            self._crop_image(self.ax, margin)
 
     def _select_clusters(self):
         def create_query(list_cl, use_label):
@@ -188,9 +191,18 @@ class SpatialBasePlot(Spatial):
 
         main_ax.set_ylim(main_ax.get_ylim()[::-1])
 
+    def _zoom_image(self, main_ax: _AxesSubplot, zoom_coord: Optional[float]):
+
+        main_ax.set_xlim(zoom_coord[0], zoom_coord[1])
+        main_ax.set_ylim(zoom_coord[2], zoom_coord[3])
+
     def _add_color_bar(self, plot, color_bar_label: str = ""):
         cb = plt.colorbar(
-            plot, aspect=10, shrink=0.5, cmap=self.cmap, label=color_bar_label
+            plot,
+            aspect=10,
+            shrink=0.5,
+            cmap=self.cmap,
+            label=color_bar_label,
         )
         cb.outline.set_visible(False)
 
@@ -240,6 +252,7 @@ class GenePlot(SpatialBasePlot):
         show_color_bar: Optional[bool] = True,
         color_bar_label: Optional[str] = "",
         crop: Optional[bool] = True,
+        zoom_coord: Optional[float] = None,
         margin: Optional[bool] = 100,
         size: Optional[float] = 7,
         image_alpha: Optional[float] = 1.0,
@@ -270,6 +283,7 @@ class GenePlot(SpatialBasePlot):
             show_axis=show_axis,
             show_image=show_image,
             show_color_bar=show_color_bar,
+            zoom_coord=zoom_coord,
             crop=crop,
             margin=margin,
             size=size,
@@ -314,9 +328,6 @@ class GenePlot(SpatialBasePlot):
         if show_color_bar:
             self._add_color_bar(plot, color_bar_label=color_bar_label)
 
-        if crop:
-            self._crop_image(self.ax, margin)
-
         if fname != None:
             self._save_output()
 
@@ -454,6 +465,7 @@ class FeaturePlot(SpatialBasePlot):
         show_color_bar: Optional[bool] = True,
         color_bar_label: Optional[str] = "",
         crop: Optional[bool] = True,
+        zoom_coord: Optional[float] = None,
         margin: Optional[bool] = 100,
         size: Optional[float] = 7,
         image_alpha: Optional[float] = 1.0,
@@ -483,6 +495,7 @@ class FeaturePlot(SpatialBasePlot):
             show_axis=show_axis,
             show_image=show_image,
             show_color_bar=show_color_bar,
+            zoom_coord=zoom_coord,
             crop=crop,
             margin=margin,
             size=size,
@@ -514,9 +527,6 @@ class FeaturePlot(SpatialBasePlot):
         if show_color_bar:
             self._add_color_bar(plot, color_bar_label=color_bar_label)
 
-        if crop:
-            self._crop_image(self.ax, margin)
-
         if fname != None:
             self._save_output()
 
@@ -624,6 +634,7 @@ class ClusterPlot(SpatialBasePlot):
         show_image: Optional[bool] = True,
         show_color_bar: Optional[bool] = True,
         crop: Optional[bool] = True,
+        zoom_coord: Optional[float] = None,
         margin: Optional[bool] = 100,
         size: Optional[float] = 5,
         image_alpha: Optional[float] = 1.0,
@@ -660,6 +671,7 @@ class ClusterPlot(SpatialBasePlot):
             show_axis=show_axis,
             show_image=show_image,
             show_color_bar=show_color_bar,
+            zoom_coord=zoom_coord,
             crop=crop,
             margin=margin,
             size=size,
@@ -674,6 +686,7 @@ class ClusterPlot(SpatialBasePlot):
         self._add_cluster_colors()
 
         self._plot_clusters()
+
         self.threshold_spots = threshold_spots
         self.text_box_size = text_box_size
         self.color_bar_size = color_bar_size
@@ -688,6 +701,7 @@ class ClusterPlot(SpatialBasePlot):
 
         if show_subcluster:
             self._add_sub_clusters()
+
         if show_trajectories:
 
             self.trajectory_node_size = trajectory_node_size
@@ -698,9 +712,6 @@ class ClusterPlot(SpatialBasePlot):
 
             self._add_trajectories()
 
-        if crop:
-            self._crop_image(self.ax, margin)
-
         if fname != None:
             self._save_output()
 
@@ -781,27 +792,8 @@ class ClusterPlot(SpatialBasePlot):
             imgcol_new = subset_spatial[:, 0] * self.scale_factor
             imgrow_new = subset_spatial[:, 1] * self.scale_factor
 
-            # if (
-            #     len(
-            #         self.query_adata.obs[
-            #             self.query_adata.obs[self.use_label] == str(label)
-            #         ][self.use_label].cat.categories
-            #     )
-            #     < 2
-            # ):
             centroids = [centroidpython(imgcol_new, imgrow_new)]
 
-            # else:
-            #     from sklearn.neighbors import NearestCentroid
-
-            #     clf = NearestCentroid()
-            #     clf.fit(
-            #         np.column_stack((imgcol_new, imgrow_new)),
-            #         np.repeat(label, len(imgcol_new)),
-            #     )
-
-            #     centroids = clf.centroids_
-
             if centroids[0][0] < 1500:
                 x = -100
                 y = 50
@@ -902,6 +894,7 @@ class ClusterPlot(SpatialBasePlot):
                             boxstyle="round",
                             alpha=1.0,
                         ),
+                        clip_on=True,
                     )
 
     def _add_trajectories(self):
@@ -995,6 +988,7 @@ class SubClusterPlot(SpatialBasePlot):
         show_image: Optional[bool] = True,
         show_color_bar: Optional[bool] = True,
         crop: Optional[bool] = True,
+        zoom_coord: Optional[float] = None,
         margin: Optional[bool] = 100,
         size: Optional[float] = 5,
         image_alpha: Optional[float] = 1.0,
@@ -1003,6 +997,7 @@ class SubClusterPlot(SpatialBasePlot):
         dpi: Optional[int] = 120,
         # subcluster plot param
         cluster: Optional[int] = 0,
+        threshold_spots: Optional[int] = 5,
         text_box_size: Optional[float] = 5,
         bbox_to_anchor: Optional[Tuple[float, float]] = (1, 1),
         **kwargs,
@@ -1020,6 +1015,7 @@ class SubClusterPlot(SpatialBasePlot):
             show_axis=show_axis,
             show_image=show_image,
             show_color_bar=show_color_bar,
+            zoom_coord=zoom_coord,
             crop=crop,
             margin=margin,
             size=size,
@@ -1032,22 +1028,29 @@ class SubClusterPlot(SpatialBasePlot):
         self.text_box_size = text_box_size
         self.cluster = cluster
 
-        self._plot_subclusters()
+        subset = self._plot_subclusters(threshold_spots)
 
-        self._add_subclusters_label()
-
-        if crop:
-            self._crop_image(self.ax, margin)
+        self._add_subclusters_label(subset)
 
         if fname != None:
             self._save_output()
 
-    def _plot_subclusters(self):
-        subset = self.adata[0].obs[
-            self.adata[0].obs[self.use_label] == str(self.cluster)
-        ]
+    def _plot_subclusters(self, threshold_spots):
+        subset = (
+            self.adata[0]
+            .obs[self.adata[0].obs[self.use_label] == str(self.cluster)]
+            .copy()
+        )
+
+        meaningful_sub = []
+        for i in subset["sub_cluster_labels"].unique():
+            if len(subset[subset["sub_cluster_labels"] == str(i)]) > threshold_spots:
+                meaningful_sub.append(i)
+
+        subset = subset[subset["sub_cluster_labels"].isin(meaningful_sub)]
+
         colors = subset["sub_cluster_labels"]
-        sub_anndata = self.adata[0][subset.index, :]
+        sub_anndata = self.adata[0][subset.index, :].copy()
         self.imgcol_new = sub_anndata.obsm["spatial"][:, 0] * self.scale_factor
         self.imgrow_new = sub_anndata.obsm["spatial"][:, 1] * self.scale_factor
 
@@ -1068,33 +1071,13 @@ class SubClusterPlot(SpatialBasePlot):
             alpha=self.cell_alpha,
         )
 
-    def _add_subclusters_label(self):
-        if (
-            len(
-                self.adata[0]
-                .obs[self.adata[0].obs[self.use_label] == str(self.cluster)][
-                    "sub_cluster_labels"
-                ]
-                .unique()
-            )
-            < 2
-        ):
-            centroids = [
-                centroidpython(
-                    self.adata[0]
-                    .obs[self.adata[0].obs[self.use_label] == str(self.cluster)][
-                        ["imagecol", "imagerow"]
-                    ]
-                    .values
-                )
-            ]
-            classes = np.array(
-                [
-                    self.adata[0].obs[
-                        self.adata[0].obs[self.use_label] == str(self.cluster)
-                    ]["sub_cluster_labels"][0]
-                ]
-            )
+        return subset
+
+    def _add_subclusters_label(self, subset):
+        if len(subset["sub_cluster_labels"].unique()) < 2:
+            print("lower than 2")
+            centroids = [centroidpython(subset[["imagecol", "imagerow"]].values)]
+            classes = np.array([subset["sub_cluster_labels"][0]])
 
         else:
             from sklearn.neighbors import NearestCentroid
@@ -1102,9 +1085,7 @@ class SubClusterPlot(SpatialBasePlot):
             clf = NearestCentroid()
             clf.fit(
                 np.column_stack((self.imgcol_new, self.imgrow_new)),
-                self.adata[0].obs[
-                    self.adata[0].obs[self.use_label] == str(self.cluster)
-                ]["sub_cluster_labels"],
+                subset["sub_cluster_labels"],
             )
 
             centroids = clf.centroids_
@@ -1161,6 +1142,7 @@ class CciPlot(GenePlot):
         show_image: Optional[bool] = True,
         show_color_bar: Optional[bool] = True,
         crop: Optional[bool] = True,
+        zoom_coord: Optional[float] = None,
         margin: Optional[bool] = 100,
         size: Optional[float] = 7,
         image_alpha: Optional[float] = 1.0,
@@ -1188,6 +1170,7 @@ class CciPlot(GenePlot):
             show_axis=show_axis,
             show_image=show_image,
             show_color_bar=show_color_bar,
+            zoom_coord=zoom_coord,
             crop=crop,
             margin=margin,
             size=size,
@@ -1229,6 +1212,7 @@ class LrResultPlot(GenePlot):
         show_image: Optional[bool] = True,
         show_color_bar: Optional[bool] = True,
         crop: Optional[bool] = True,
+        zoom_coord: Optional[float] = None,
         margin: Optional[bool] = 100,
         size: Optional[float] = 7,
         image_alpha: Optional[float] = 1.0,
@@ -1278,6 +1262,7 @@ class LrResultPlot(GenePlot):
             show_axis=show_axis,
             show_image=show_image,
             show_color_bar=show_color_bar,
+            zoom_coord=zoom_coord,
             crop=crop,
             margin=margin,
             size=size,
