@@ -36,6 +36,7 @@ def cluster_plot(
     show_axis: Optional[bool] = False,
     show_image: Optional[bool] = True,
     show_color_bar: Optional[bool] = True,
+    zoom_coord: Optional[float] = None,
     crop: Optional[bool] = True,
     margin: Optional[bool] = 100,
     size: Optional[float] = 5,
@@ -62,7 +63,7 @@ def cluster_plot(
 ) -> Optional[AnnData]:
 
     """\
-    Allows the visualization of a clustering results as the discretes values
+    Allows the visualization of a cluster results as the discretes values
     of dot points in the Spatial transcriptomics array. We also support to
     visualize the spatial trajectory results
 
@@ -96,6 +97,7 @@ def cluster_plot(
         show_axis=show_axis,
         show_image=show_image,
         show_color_bar=show_color_bar,
+        zoom_coord=zoom_coord,
         crop=crop,
         margin=margin,
         size=size,
