@@ -11,10 +11,10 @@ from typing import Tuple  # Classes
 from anndata import AnnData
 import warnings
 
-from .classes import GenePlot
-from .classes_bokeh import BokehGenePlot
-from ._docs import doc_spatial_base_plot, doc_gene_plot
-from ..utils import Empty, _empty, _AxesSubplot, _docs_params
+from stlearn.plotting.classes import GenePlot
+from stlearn.plotting.classes_bokeh import BokehGenePlot
+from stlearn.plotting._docs import doc_spatial_base_plot, doc_gene_plot
+from stlearn.utils import Empty, _empty, _AxesSubplot, _docs_params
 
 from bokeh.io import push_notebook, output_notebook
 from bokeh.plotting import show
@@ -33,11 +33,14 @@ def gene_plot(
     cmap: Optional[str] = "Spectral_r",
     use_label: Optional[str] = None,
     list_clusters: Optional[list] = None,
-    ax: Optional[_AxesSubplot] = None,
+    ax: Optional[matplotlib.axes._subplots.Axes] = None,
+    fig: Optional[matplotlib.figure.Figure] = None,
     show_plot: Optional[bool] = True,
     show_axis: Optional[bool] = False,
     show_image: Optional[bool] = True,
     show_color_bar: Optional[bool] = True,
+    color_bar_label: Optional[str] = "",
+    zoom_coord: Optional[float] = None,
     crop: Optional[bool] = True,
     margin: Optional[bool] = 100,
     size: Optional[float] = 7,
@@ -46,6 +49,8 @@ def gene_plot(
     use_raw: Optional[bool] = False,
     fname: Optional[str] = None,
     dpi: Optional[int] = 120,
+    vmin: Optional[float] = None,
+    vmax: Optional[float] = None,
 ) -> Optional[AnnData]:
     """\
     Allows the visualization of a single gene or multiple genes as the values
@@ -78,10 +83,13 @@ def gene_plot(
         use_label=use_label,
         list_clusters=list_clusters,
         ax=ax,
+        fig=fig,
         show_plot=show_plot,
         show_axis=show_axis,
         show_image=show_image,
         show_color_bar=show_color_bar,
+        color_bar_label=color_bar_label,
+        zoom_coord=zoom_coord,
         crop=crop,
         margin=margin,
         size=size,
@@ -90,6 +98,8 @@ def gene_plot(
         use_raw=use_raw,
         fname=fname,
         dpi=dpi,
+        vmin=vmin,
+        vmax=vmax,
     )
 
 
