@@ -15,14 +15,14 @@ def localization(
 ) -> Optional[AnnData]:
 
     """\
-    Perform local clustering by using DBSCAN.
+    Perform local cluster by using DBSCAN.
 
     Parameters
     ----------
     adata
         Annotated data matrix.
     use_label
-        Use label result of clustering method.
+        Use label result of cluster method.
     eps
         The maximum distance between two samples for one to be considered as
         in the neighborhood of the other. This is not a maximum bound on the
@@ -42,7 +42,7 @@ def localization(
         adata.obs = adata.obs.drop("sub_cluster_labels", axis=1)
 
     pd.set_option("mode.chained_assignment", None)
-    subclusters = pd.Series()
+    subclusters_list = []
     for i in adata.obs[use_label].unique():
 
         tmp = adata.obs[adata.obs[use_label] == i]
@@ -57,7 +57,9 @@ def localization(
         for label in labels:
             sublabels.append(str(i) + "_" + str(label))
         tmp["sub_labels"] = sublabels
-        subclusters = subclusters.append(tmp["sub_labels"])
+        subclusters_list.append(tmp["sub_labels"])
+
+    subclusters = pd.concat(subclusters_list)
     pd.reset_option("mode.chained_assignment")
 
     adata.obs = pd.merge(
@@ -66,9 +68,10 @@ def localization(
         left_index=True,
         right_index=True,
     )
+
     # Convert to numeric
     converted = dict(enumerate(adata.obs["sub_cluster_labels"].unique()))
-    inv_map = {v: k for k, v in converted.items()}
+    inv_map = {v: str(k) for k, v in converted.items()}
     adata.obs["sub_cluster_labels"] = adata.obs["sub_cluster_labels"].replace(inv_map)
 
     adata.obs["sub_cluster_labels"] = pd.Categorical(
