@@ -30,7 +30,7 @@ def global_level(
     list_clusters
         Setup a list of cluster to perform pseudo-space-time
     use_label
-        Use label result of clustering method.
+        Use label result of cluster method.
     return_graph
         Return PTS graph
     w
@@ -170,7 +170,7 @@ def global_level(
         node_convert[pair[1]] = pair[0]
 
     adata.uns["PTS_graph"] = {}
-    adata.uns["PTS_graph"]["graph"] = nx.to_scipy_sparse_matrix(H_sub)
+    adata.uns["PTS_graph"]["graph"] = nx.to_scipy_sparse_array(H_sub)
     adata.uns["PTS_graph"]["node_dict"] = node_convert
 
     if return_graph:
