@@ -8,8 +8,10 @@ from .local_level import local_level
 def pseudotimespace_global(
     adata: AnnData,
     use_label: str = "louvain",
+    use_rep: str = "X_pca",
+    n_dims: int = 40,
     list_clusters: list = [],
-    w: float = None,
+    model: str = "spatial",
     step=0.01,
     k=10,
 ) -> Optional[AnnData]:
@@ -22,7 +24,7 @@ def pseudotimespace_global(
     adata
         Annotated data matrix.
     use_label
-        Use label result of clustering method.
+        Use label result of cluster method.
     list_clusters
         List of cluster used to reconstruct spatial trajectory.
     w
@@ -36,13 +38,28 @@ def pseudotimespace_global(
     Anndata
     """
 
-    if w is None:
+    if model == "mixed":
 
         w = weight_optimizing_global(
             adata, use_label=use_label, list_clusters=list_clusters, step=step, k=k
         )
+    elif model == "spatial":
+        w = 0
+    elif model == "gene_expression":
+        w = 1
+    else:
+        raise ValidationError(
+            "Please choose the right model! Available models: 'mixed', 'spatial' and 'gene_expression' "
+        )
 
-    global_level(adata, use_label=use_label, list_clusters=list_clusters, w=w)
+    global_level(
+        adata,
+        use_label=use_label,
+        list_clusters=list_clusters,
+        w=w,
+        use_rep=use_rep,
+        n_dims=n_dims,
+    )
 
 
 def pseudotimespace_local(
@@ -60,7 +77,7 @@ def pseudotimespace_local(
     adata
         Annotated data matrix.
     use_label
-        Use label result of clustering method.
+        Use label result of cluster method.
     cluster
         Cluster used to reconstruct intraregional spatial trajectory.
     w
